FedorovWynn finds an optimal design using some sensitivity function and a Fedorov-Wynn-type algorithm.FedorovWynn(sensF, tol, maxIter = 10000)function(x=NULL, desw=NULL, desx=NULL, mod=NULL), a sensitivity function.
It's attribute "defaults" shall contain x and sensF(desw=w) shall return sensitivities for each point in x respectivFedorovWynn returns an object of class "desigh".
See design for its structural definition.Dsensitivity and it's return value for a reference implementation of a function complying with the requirements for sensF.The algorithm starts from a uniform weight design.
In each iteration weight is redistributed to the point which has the highest sensitivity.
Sequence: 1/i.
The algorithm stops when all sensitivities are below a specified tolerance level or the maximum number of iterations is reached.
Wynn, Henry P. (1970) The Sequential Generation of D-Optimum Experimental Designs. The Annals of Mathematical Statistics, 41(5):1655-1664.
Dsensitivity, design