nint_scatDim: Scatter Dimension
Description
nint_scatDim is defined by a sequence of values.
Together with other scatter dimensions it defines a sparse grid.Value
nint_scatDim returns its argument with the dimension type attribute set to nint_TYPE_SCAT_DIM.
Details
Imagine using cbind to create a row matrix of points.