FedorovWynn finds a D- or Ds-optimal design using a Fedorov-Wynn-type algorithm.FedorovWynn(mod, sNames = NULL, names = NULL, tolAbs = Inf,
tolRel = 1e-04, maxIter = 10000)FedorovWynn returns an object of class "desigh".
An object of class "desigh" is a list containing the following components:
mod$x.sNames and names default to the set of parameters for which the Fisher information is available.The algorithm starts from a uniform weight design.
In each iteration weight is redistributed to the point which has the highest sensitivity.
Sequence: 1/i.
The algorithm stops when all sensitivities are below a certain absolute and relative tolerance level, or the maximum number of iterations is reached.
Wynn, Henry P. (1970) The Sequential Generation of D-Optimum Experimental Designs. The Annals of Mathematical Statistics, 41(5):1655-1664.
param, getM, reduce, plot.desigh, Defficiency, update.desigh